
.. _class:

Classes and invariants
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   private_data_and_classes.rst
   what_is_a_class.rst
   complex_numbers.rst
   accessor_functions.rst
   output.rst
   a_function_on_complex_numbers.rst
   another_function_on_complex_numbers.rst
   invariants.rst
   preconditions.rst
   private_functions.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst
